@@ -128,6 +128,7 @@ class TenRoster(Roster):
 class MLBRoster(Roster):
     POSITION_ORDER = {
         'P': 0,
+        'RP': 0,
         'SP': 0,
         'C': 1,
         '1B': 2,
@@ -135,7 +136,6 @@ class MLBRoster(Roster):
         '3B': 4,
         'SS': 5,
         'OF': 6,
-        'RP': 7,
     }
 
 
@@ -217,6 +217,7 @@ class RosterSelect:
             # XFL uses the same positions as NFL
             'XFL': NFLRoster(),
             'TEN': TenRoster(),
+            'CSGO_SHOWDOWN': ShowdownRoster(),
         }
         return roster_dict[league]
 
@@ -240,6 +241,7 @@ class Player(object):
         position_lock=False,
         ban=False,
         multi_position=False,
+        kv_store={},
     ):
         self.pos = pos
         self.name = name
@@ -257,6 +259,7 @@ class Player(object):
         self.position_ban = False
         self.multi_position = multi_position
         self.possible_positions = possible_positions
+        self.kv_store = kv_store
 
     def get_player_id(self, player_map):
         return player_map[self.name + ' ' + self.possible_positions]
@@ -352,6 +355,12 @@ class Player(object):
             return 'F'
         return 'C'
 
+    @property
+    def mlb_general_position(self):
+        if self.pos in {'SP', 'RP'}:
+            return 'P'
+        return self.pos
+
     @property
     def short_name(self):
         s = self.name.split()
